<?php
/**
 * elsa Theme Customizer.
 *
 * @package elsa
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function elsa_customize_register( $wp_customize ) {

    $wp_customize->add_section( 
        'elsa_featured_section', 
        array(
        'title'     => __( 'ELSA Countdown', 'elsa' ),
        'priority'  => 1,
    ) );

	$wp_customize->add_setting(
		'elsa_countdown_title',
		array(
			'sanitize_callback' => 'sanitize_text_field',
			'transport' => 'refresh',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Control(
			$wp_customize,
			'elsa_countdown_title_control',
			array(
				'label'     => __( 'Countdown Title', 'elsa' ),
				'section'   => 'elsa_featured_section',
				'settings'  => 'elsa_countdown_title',
				'type'      => 'text',
			)
		)
	);

	// Add A Date Picker
    require_once get_template_directory() . '/inc/date/date-picker-custom-control.php';
    $wp_customize->add_setting( 'elsa_countdown_setting', 
        array(
            'default'     => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport'   => 'refresh',
        ) 
    );
    $wp_customize->add_control( new Elsa_Date_Picker_Custom_Control( $wp_customize, 'elsa_countdown_control', 
        array(
            'label'       => __( 'Countdown date and time', 'elsa' ),
            'section'     => 'elsa_featured_section',
            'settings'    => 'elsa_countdown_setting',
            ) 
        ) 
    ); 

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
}
add_action( 'customize_register', 'elsa_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function elsa_customize_preview_js() {
	wp_enqueue_script( 'elsa-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20160308.001', true );
}
add_action( 'customize_preview_init', 'elsa_customize_preview_js' );

function elsa_customize_control_js() {
    wp_enqueue_script( 'elsa-customizer-controls', get_template_directory_uri() . '/js/customizer-controls.js', array( 'customize-controls' ), '20160214.003', true );
}
add_action( 'customize_controls_init', 'elsa_customize_control_js' );
